@@ -633,6 +633,12 @@ class Object(Hirarchy):
                 return property_set
         return None
 
+    @property
+    def ident_value(self):
+        if not self.is_concept:
+            return self.ident_attrib.value[0]
+        return None
+
 
 class Aggregation(Hirarchy):
     _registry: set[Aggregation] = set()
@@ -656,11 +662,15 @@ class Aggregation(Hirarchy):
     @property
     def parent_connection(self) -> int:
         """
+        NO PARENT = 0
         AGGREGATION = 1
         INHERITANCE = 2
         AGGREGATION+INHERITANCE =3
         :return:
         """
+        if self.parent is None:
+            return 0
+
         return self.parent.connection_dict[self]
 
     def add_child(self, child: Aggregation, connection_type: int = constants.AGGREGATION) -> Aggregation:
